@@ -106,7 +106,7 @@ ggit_diff_options_free (GgitDiffOptions *diff_options)
  * @n_interhunk_lines: the number of interhunk lines, default is 3.
  * @old_prefix: (allow-none): the old prefix, defaults to "a".
  * @new_prefix: (allow-none): the new prefix, defaults to "b".
- * @pathspec: (allow-none): which paths to show, defaults to showing all paths.
+ * @pathspec: (allow-none) (array zero-terminated=1): which paths to show, defaults to showing all paths.
  *
  * Creates a new #GgitDiffOptions for use in creating a #GgitDiff.
  *
@@ -121,19 +121,20 @@ ggit_diff_options_new (GgitDiffOption  flags,
                        const gchar   **pathspec)
 {
 	GgitDiffOptions *diff_options;
-	git_diff_options *gdiff_options;
+	git_diff_options gdiff_options = GIT_DIFF_OPTIONS_INIT;
 
 	diff_options = g_slice_new (GgitDiffOptions);
-	gdiff_options = &diff_options->diff_options;
 
-	gdiff_options->flags = flags;
-	gdiff_options->context_lines = n_context_lines;
-	gdiff_options->interhunk_lines = n_interhunk_lines;
-	gdiff_options->old_prefix = old_prefix == NULL ? NULL : g_strdup (old_prefix);
-	gdiff_options->new_prefix = new_prefix == NULL ? NULL : g_strdup (new_prefix);
+	gdiff_options.flags = flags;
+	gdiff_options.context_lines = n_context_lines;
+	gdiff_options.interhunk_lines = n_interhunk_lines;
+	gdiff_options.old_prefix = old_prefix == NULL ? NULL : g_strdup (old_prefix);
+	gdiff_options.new_prefix = new_prefix == NULL ? NULL : g_strdup (new_prefix);
+
 	ggit_utils_get_git_strarray_from_str_array (pathspec,
-	                                            &gdiff_options->pathspec);
+	                                            &gdiff_options.pathspec);
 
+	diff_options->diff_options = gdiff_options;
 	return diff_options;
 }
 
