@@ -982,6 +982,180 @@ ggit_packbuilder_stage_get_type (void)
 	return the_type;
 }
 
+GType
+ggit_checkout_strategy_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GFlagsValue values[] = {
+			{ GGIT_CHECKOUT_NONE,
+			  "GGIT_CHECKOUT_NONE",
+			  "none" },
+			{ GGIT_CHECKOUT_SAFE,
+			  "GGIT_CHECKOUT_SAFE",
+			  "safe" },
+			{ GGIT_CHECKOUT_SAFE_CREATE,
+			  "GGIT_CHECKOUT_SAFE_CREATE",
+			  "safe-create" },
+			{ GGIT_CHECKOUT_FORCE,
+			  "GGIT_CHECKOUT_FORCE",
+			  "force" },
+			{ GGIT_CHECKOUT_ALLOW_CONFLICTS,
+			  "GGIT_CHECKOUT_ALLOW_CONFLICTS",
+			  "allow-conflicts" },
+			{ GGIT_CHECKOUT_REMOVE_UNTRACKED,
+			  "GGIT_CHECKOUT_REMOVE_UNTRACKED",
+			  "remove-untracked" },
+			{ GGIT_CHECKOUT_REMOVE_IGNORED,
+			  "GGIT_CHECKOUT_REMOVE_IGNORED",
+			  "remove-ignored" },
+			{ GGIT_CHECKOUT_UPDATE_ONLY,
+			  "GGIT_CHECKOUT_UPDATE_ONLY",
+			  "update-only" },
+			{ GGIT_CHECKOUT_DONT_UPDATE_INDEX,
+			  "GGIT_CHECKOUT_DONT_UPDATE_INDEX",
+			  "dont-update-index" },
+			{ GGIT_CHECKOUT_NO_REFRESH,
+			  "GGIT_CHECKOUT_NO_REFRESH",
+			  "no-refresh" },
+			{ GGIT_CHECKOUT_SKIP_UNMERGED,
+			  "GGIT_CHECKOUT_SKIP_UNMERGED",
+			  "skip-unmerged" },
+			{ GGIT_CHECKOUT_USE_OURS,
+			  "GGIT_CHECKOUT_USE_OURS",
+			  "use-ours" },
+			{ GGIT_CHECKOUT_USE_THEIRS,
+			  "GGIT_CHECKOUT_USE_THEIRS",
+			  "use-theirs" },
+			{ GGIT_CHECKOUT_DISABLE_PATHSPEC_MATCH,
+			  "GGIT_CHECKOUT_DISABLE_PATHSPEC_MATCH",
+			  "disable-pathspec-match" },
+			{ GGIT_CHECKOUT_SKIP_LOCKED_DIRECTORIES,
+			  "GGIT_CHECKOUT_SKIP_LOCKED_DIRECTORIES",
+			  "skip-locked-directories" },
+			{ GGIT_CHECKOUT_DONT_OVERWRITE_IGNORED,
+			  "GGIT_CHECKOUT_DONT_OVERWRITE_IGNORED",
+			  "dont-overwrite-ignored" },
+			{ GGIT_CHECKOUT_CONFLICT_STYLE_MERGE,
+			  "GGIT_CHECKOUT_CONFLICT_STYLE_MERGE",
+			  "conflict-style-merge" },
+			{ GGIT_CHECKOUT_CONFLICT_STYLE_DIFF3,
+			  "GGIT_CHECKOUT_CONFLICT_STYLE_DIFF3",
+			  "conflict-style-diff3" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_flags_register_static (
+				g_intern_static_string ("GgitCheckoutStrategy"),
+				values);
+	}
+	return the_type;
+}
+
+GType
+ggit_checkout_notify_flags_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GFlagsValue values[] = {
+			{ GGIT_CHECKOUT_NOTIFY_NONE,
+			  "GGIT_CHECKOUT_NOTIFY_NONE",
+			  "none" },
+			{ GGIT_CHECKOUT_NOTIFY_CONFLICT,
+			  "GGIT_CHECKOUT_NOTIFY_CONFLICT",
+			  "conflict" },
+			{ GGIT_CHECKOUT_NOTIFY_DIRTY,
+			  "GGIT_CHECKOUT_NOTIFY_DIRTY",
+			  "dirty" },
+			{ GGIT_CHECKOUT_NOTIFY_UPDATED,
+			  "GGIT_CHECKOUT_NOTIFY_UPDATED",
+			  "updated" },
+			{ GGIT_CHECKOUT_NOTIFY_UNTRACKED,
+			  "GGIT_CHECKOUT_NOTIFY_UNTRACKED",
+			  "untracked" },
+			{ GGIT_CHECKOUT_NOTIFY_IGNORED,
+			  "GGIT_CHECKOUT_NOTIFY_IGNORED",
+			  "ignored" },
+			{ GGIT_CHECKOUT_NOTIFY_ALL,
+			  "GGIT_CHECKOUT_NOTIFY_ALL",
+			  "all" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_flags_register_static (
+				g_intern_static_string ("GgitCheckoutNotifyFlags"),
+				values);
+	}
+	return the_type;
+}
+
+GType
+ggit_diff_find_flags_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GFlagsValue values[] = {
+			{ GGIT_DIFF_FIND_BY_CONFIG,
+			  "GGIT_DIFF_FIND_BY_CONFIG",
+			  "find-by-config" },
+			{ GGIT_DIFF_FIND_RENAMES,
+			  "GGIT_DIFF_FIND_RENAMES",
+			  "find-renames" },
+			{ GGIT_DIFF_FIND_RENAMES_FROM_REWRITES,
+			  "GGIT_DIFF_FIND_RENAMES_FROM_REWRITES",
+			  "find-renames-from-rewrites" },
+			{ GGIT_DIFF_FIND_COPIES,
+			  "GGIT_DIFF_FIND_COPIES",
+			  "find-copies" },
+			{ GGIT_DIFF_FIND_COPIES_FROM_UNMODIFIED,
+			  "GGIT_DIFF_FIND_COPIES_FROM_UNMODIFIED",
+			  "find-copies-from-unmodified" },
+			{ GGIT_DIFF_FIND_REWRITES,
+			  "GGIT_DIFF_FIND_REWRITES",
+			  "find-rewrites" },
+			{ GGIT_DIFF_BREAK_REWRITES,
+			  "GGIT_DIFF_BREAK_REWRITES",
+			  "break-rewrites" },
+			{ GGIT_DIFF_FIND_AND_BREAK_REWRITES,
+			  "GGIT_DIFF_FIND_AND_BREAK_REWRITES",
+			  "find-and-break-rewrites" },
+			{ GGIT_DIFF_FIND_FOR_UNTRACKED,
+			  "GGIT_DIFF_FIND_FOR_UNTRACKED",
+			  "find-for-untracked" },
+			{ GGIT_DIFF_FIND_ALL,
+			  "GGIT_DIFF_FIND_ALL",
+			  "find-all" },
+			{ GGIT_DIFF_FIND_IGNORE_LEADING_WHITESPACE,
+			  "GGIT_DIFF_FIND_IGNORE_LEADING_WHITESPACE",
+			  "find-ignore-leading-whitespace" },
+			{ GGIT_DIFF_FIND_IGNORE_WHITESPACE,
+			  "GGIT_DIFF_FIND_IGNORE_WHITESPACE",
+			  "find-ignore-whitespace" },
+			{ GGIT_DIFF_FIND_DONT_IGNORE_WHITESPACE,
+			  "GGIT_DIFF_FIND_DONT_IGNORE_WHITESPACE",
+			  "find-dont-ignore-whitespace" },
+			{ GGIT_DIFF_FIND_EXACT_MATCH_ONLY,
+			  "GGIT_DIFF_FIND_EXACT_MATCH_ONLY",
+			  "find-exact-match-only" },
+			{ GGIT_DIFF_BREAK_REWRITES_FOR_RENAMES_ONLY,
+			  "GGIT_DIFF_BREAK_REWRITES_FOR_RENAMES_ONLY",
+			  "break-rewrites-for-renames-only" },
+			{ GGIT_DIFF_FIND_REMOVE_UNMODIFIED,
+			  "GGIT_DIFF_FIND_REMOVE_UNMODIFIED",
+			  "find-remove-unmodified" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_flags_register_static (
+				g_intern_static_string ("GgitDiffFindFlags"),
+				values);
+	}
+	return the_type;
+}
+
 
 /* Generated data ends here */
 
