@@ -464,7 +464,29 @@ ggit_ref_lookup (GgitRef  *ref,
 }
 
 /**
- * ggit_ref_get_reflog:
+ * ggit_ref_has_log:
+ * @ref: a #GgitRef.
+ *
+ * Get whether @ref has an existing log.
+ *
+ * Returns: %TRUE if @ref has a log, %FALSE otherwise.
+ *
+ **/
+gboolean
+ggit_ref_has_log (GgitRef *ref)
+{
+	git_reference *nref;
+
+	g_return_val_if_fail (GGIT_IS_REF (ref), FALSE);
+
+	nref = _ggit_native_get (ref);
+
+	return git_reference_has_log (git_reference_owner (nref),
+	                              git_reference_name (nref)) == 1;
+}
+
+/**
+ * ggit_ref_get_log:
  * @ref: a #GgitRef.
  * @error: a #GError for error reporting, or %NULL.
  *
@@ -474,8 +496,8 @@ ggit_ref_lookup (GgitRef  *ref,
  * Returns: (transfer full): the reflog.
  */
 GgitReflog *
-ggit_ref_get_reflog (GgitRef  *ref,
-                     GError  **error)
+ggit_ref_get_log (GgitRef  *ref,
+                  GError  **error)
 {
 	git_reflog *reflog;
 	git_reference *nref;
@@ -500,15 +522,15 @@ ggit_ref_get_reflog (GgitRef  *ref,
 }
 
 /**
- * ggit_ref_delete_reflog:
+ * ggit_ref_delete_log:
  * @ref: a #GgitRef.
  * @error: a #GError for error reporting, or %NULL.
  *
- * Deletes the reflog for @ref, on error @error is set.
+ * Deletes the log for @ref, on error @error is set.
  */
 void
-ggit_ref_delete_reflog (GgitRef  *ref,
-                        GError  **error)
+ggit_ref_delete_log (GgitRef  *ref,
+                     GError  **error)
 {
 	git_reference *nref;
 	gint ret;
@@ -578,4 +600,21 @@ ggit_ref_is_branch (GgitRef *ref)
 	return git_reference_is_branch (_ggit_native_get (ref));
 }
 
+/**
+ * ggit_ref_is_note:
+ * @ref: a #GgitRef.
+ *
+ * Check whether the reference is a note.
+ *
+ * Returns: %TRUE if the reference is a note, %FALSE otherwise.
+ *
+ **/
+gboolean
+ggit_ref_is_note (GgitRef *ref)
+{
+	g_return_val_if_fail (ref != NULL, FALSE);
+
+	return git_reference_is_note (_ggit_native_get (ref));
+}
+
 /* ex:set ts=8 noet: */
