@@ -33,6 +33,7 @@
 #include <libgit2-glib/ggit-tree.h>
 #include <libgit2-glib/ggit-branch.h>
 #include <libgit2-glib/ggit-blob-output-stream.h>
+#include <libgit2-glib/ggit-checkout-options.h>
 
 G_BEGIN_DECLS
 
@@ -173,6 +174,23 @@ GgitOId            *ggit_repository_create_tag_lightweight (
                                                        GgitCreateFlags        flags,
                                                        GError               **error);
 
+GgitOId            *ggit_repository_create_tag_annotation (
+                                                       GgitRepository        *repository,
+                                                       const gchar           *tag_name,
+                                                       GgitObject            *target,
+                                                       GgitSignature         *signature,
+                                                       const gchar           *message,
+                                                       GError               **error);
+
+gboolean            ggit_repository_delete_tag        (GgitRepository        *repository,
+                                                       const gchar           *name,
+                                                       GError               **error);
+
+gboolean            ggit_repository_tag_foreach       (GgitRepository        *repository,
+                                                       GgitTagCallback        callback,
+                                                       gpointer               user_data,
+                                                       GError               **error);
+
 GgitTreeBuilder    *ggit_repository_create_tree_builder_from_tree (
                                                        GgitRepository        *repository,
                                                        GgitTree              *tree,
@@ -196,6 +214,10 @@ GgitIndexEntry     *ggit_repository_create_index_entry_for_path (
 gchar             **ggit_repository_list_tags         (GgitRepository        *repository,
                                                        GError               **error);
 
+gchar             **ggit_repository_list_tags_match   (GgitRepository        *repository,
+                                                       const gchar           *pattern,
+                                                       GError               **error);
+
 GgitBranch         *ggit_repository_create_branch     (GgitRepository        *repository,
                                                        const gchar           *branch_name,
                                                        GgitObject            *target,
@@ -205,7 +227,7 @@ GgitBranch         *ggit_repository_create_branch     (GgitRepository        *re
                                                        GError               **error);
 
 GgitBranchEnumerator *ggit_repository_enumerate_branches (GgitRepository        *repository,
-                                                          GgitBranchType         list_flags,
+                                                          GgitBranchType         list_type,
                                                           GError               **error);
 
 GgitBranch         *ggit_repository_lookup_branch     (GgitRepository        *repository,
@@ -287,6 +309,11 @@ void                ggit_repository_reset              (GgitRepository
                                                         const gchar             *log_message,
                                                         GError                 **error);
 
+void                ggit_repository_reset_default      (GgitRepository          *repository,
+                                                        GgitObject              *target,
+                                                        const gchar * const     *pathspecs,
+                                                        GError                 **error);
+
 GgitObject         *ggit_repository_revparse          (GgitRepository        *repository,
                                                        const gchar           *spec,
                                                        GError               **error);
@@ -313,6 +340,11 @@ void                ggit_repository_get_ahead_behind  (GgitRepository        *re
                                                        gsize                 *behind,
                                                        GError               **error);
 
+gboolean            ggit_repository_get_descendant_of (GgitRepository        *repository,
+                                                       GgitOId               *commit,
+                                                       GgitOId               *ancestor,
+                                                       GError               **error);
+
 GgitBlame          *ggit_repository_blame_file        (GgitRepository        *repository,
                                                        GFile                 *file,
                                                        GgitBlameOptions      *blame_options,
@@ -324,6 +356,25 @@ const gchar        *ggit_repository_get_attribute     (GgitRepository
                                                        GgitAttributeCheckFlags   flags,
                                                        GError                  **error);
 
+gboolean            ggit_repository_checkout_head     (GgitRepository           *repository,
+                                                       GgitCheckoutOptions      *options,
+                                                       GError                  **error);
+
+gboolean            ggit_repository_checkout_index    (GgitRepository           *repository,
+                                                       GgitIndex                *index,
+                                                       GgitCheckoutOptions      *options,
+                                                       GError                  **error);
+
+gboolean            ggit_repository_checkout_tree     (GgitRepository           *repository,
+                                                       GgitObject               *tree,
+                                                       GgitCheckoutOptions      *options,
+                                                       GError                  **error);
+
+gboolean            ggit_repository_revert            (GgitRepository           *repository,
+                                                       GgitCommit               *commit,
+                                                       GgitRevertOptions        *options,
+                                                       GError                  **error);
+
 G_END_DECLS
 
 #endif /* __GGIT_REPOSITORY_H__ */
