@@ -95,6 +95,27 @@ typedef struct _GgitConfigEntry GgitConfigEntry;
  */
 typedef struct _GgitCred GgitCred;
 
+/**
+ * GgitCredSshInteractive:
+ *
+ * Represents a ssh interactive credential.
+ */
+typedef struct _GgitCredSshInteractive GgitCredSshInteractive;
+
+/**
+ * GgitCredSshInteractivePrompt:
+ *
+ * Represents a ssh interactive prompt.
+ */
+typedef struct _GgitCredSshInteractivePrompt GgitCredSshInteractivePrompt;
+
+/**
+ * GgitCredSshKeyFromAgent:
+ *
+ * Represents a ssh key agent credential.
+ */
+typedef struct _GgitCredSshKeyFromAgent GgitCredSshKeyFromAgent;
+
 /**
  * GgitCredPlaintext:
  *
@@ -123,6 +144,13 @@ typedef struct _GgitDiffDelta GgitDiffDelta;
  */
 typedef struct _GgitDiffFile GgitDiffFile;
 
+/**
+ * GgitDiffFindOptions:
+ *
+ * Represents options for finding diff similarity.
+ */
+typedef struct _GgitDiffFindOptions GgitDiffFindOptions;
+
 /**
  * GgitDiffHunk:
  *
@@ -383,6 +411,20 @@ typedef struct _GgitTreeBuilder GgitTreeBuilder;
  */
 typedef struct _GgitBlameOptions GgitBlameOptions;
 
+/**
+ * GgitCheckoutOptions:
+ *
+ * Represents the options used when doign a checkout.
+ */
+typedef struct _GgitCheckoutOptions GgitCheckoutOptions;
+
+/**
+ * GgitRevertOptions:
+ *
+ * Represents the options used when reverting.
+ */
+typedef struct _GgitRevertOptions GgitRevertOptions;
+
 /**
  * GgitBranchType:
  * @GGIT_BRANCH_LOCAL: specifies a local branch.
@@ -955,6 +997,59 @@ typedef enum
 	GGIT_PACKBUILDER_STAGE_DELTAFICATION  = 1
 } GgitPackbuilderStage;
 
+typedef enum
+{
+	GGIT_CHECKOUT_NONE                    = 0,
+	GGIT_CHECKOUT_SAFE                    = (1u << 0),
+	GGIT_CHECKOUT_SAFE_CREATE             = (1u << 1),
+	GGIT_CHECKOUT_FORCE                   = (1u << 2),
+	GGIT_CHECKOUT_ALLOW_CONFLICTS         = (1u << 4),
+	GGIT_CHECKOUT_REMOVE_UNTRACKED        = (1u << 5),
+	GGIT_CHECKOUT_REMOVE_IGNORED          = (1u << 6),
+	GGIT_CHECKOUT_UPDATE_ONLY             = (1u << 7),
+	GGIT_CHECKOUT_DONT_UPDATE_INDEX       = (1u << 8),
+	GGIT_CHECKOUT_NO_REFRESH              = (1u << 9),
+	GGIT_CHECKOUT_SKIP_UNMERGED           = (1u << 10),
+	GGIT_CHECKOUT_USE_OURS                = (1u << 11),
+	GGIT_CHECKOUT_USE_THEIRS              = (1u << 12),
+	GGIT_CHECKOUT_DISABLE_PATHSPEC_MATCH  = (1u << 13),
+	GGIT_CHECKOUT_SKIP_LOCKED_DIRECTORIES = (1u << 18),
+	GGIT_CHECKOUT_DONT_OVERWRITE_IGNORED  = (1u << 19),
+	GGIT_CHECKOUT_CONFLICT_STYLE_MERGE    = (1u << 20),
+	GGIT_CHECKOUT_CONFLICT_STYLE_DIFF3    = (1u << 21)
+} GgitCheckoutStrategy;
+
+typedef enum {
+	GGIT_CHECKOUT_NOTIFY_NONE      = 0,
+	GGIT_CHECKOUT_NOTIFY_CONFLICT  = (1u << 0),
+	GGIT_CHECKOUT_NOTIFY_DIRTY     = (1u << 1),
+	GGIT_CHECKOUT_NOTIFY_UPDATED   = (1u << 2),
+	GGIT_CHECKOUT_NOTIFY_UNTRACKED = (1u << 3),
+	GGIT_CHECKOUT_NOTIFY_IGNORED   = (1u << 4),
+
+	GGIT_CHECKOUT_NOTIFY_ALL       = 0x0FFFFu
+} GgitCheckoutNotifyFlags;
+
+typedef enum {
+	GGIT_DIFF_FIND_BY_CONFIG                  = 0,
+	GGIT_DIFF_FIND_RENAMES                    = (1u << 0),
+	GGIT_DIFF_FIND_RENAMES_FROM_REWRITES      = (1u << 1),
+	GGIT_DIFF_FIND_COPIES                     = (1u << 2),
+	GGIT_DIFF_FIND_COPIES_FROM_UNMODIFIED     = (1u << 3),
+	GGIT_DIFF_FIND_REWRITES                   = (1u << 4),
+	GGIT_DIFF_BREAK_REWRITES                  = (1u << 5),
+	GGIT_DIFF_FIND_AND_BREAK_REWRITES         = (GGIT_DIFF_FIND_REWRITES |
+	                                             GGIT_DIFF_BREAK_REWRITES),
+	GGIT_DIFF_FIND_FOR_UNTRACKED              = (1u << 6),
+	GGIT_DIFF_FIND_ALL                        = (0x0ff),
+	GGIT_DIFF_FIND_IGNORE_LEADING_WHITESPACE  = 0,
+	GGIT_DIFF_FIND_IGNORE_WHITESPACE          = (1u << 12),
+	GGIT_DIFF_FIND_DONT_IGNORE_WHITESPACE     = (1u << 13),
+	GGIT_DIFF_FIND_EXACT_MATCH_ONLY           = (1u << 14),
+	GGIT_DIFF_BREAK_REWRITES_FOR_RENAMES_ONLY = (1u << 15),
+	GGIT_DIFF_FIND_REMOVE_UNMODIFIED          = (1u << 16),
+} GgitDiffFindFlags;
+
 /**
  * GgitConfigCallback:
  * @entry: a #GgitConfigEntry.
@@ -1149,6 +1244,21 @@ typedef gint (* GgitSubmoduleCallback) (GgitSubmodule *submodule,
                                         const gchar   *name,
                                         gpointer       user_data);
 
+/**
+ * GgitTagCallback:
+ * @name: the tag name.
+ * @tag_oid: the tag oid.
+ * @user_data: (closure): user-suplied data.
+ *
+ * When iterating over all the tags, callback that will be
+ * issued per entry. See ggit_repository_tag_foreach().
+ *
+ * Returns: 0 to go continue or a #GgitError in case there was an error.
+ */
+typedef gint (* GgitTagCallback) (const gchar *name,
+                                  GgitOId     *tag_oid,
+                                  gpointer    *user_data);
+
 /**
  * GgitTransferProgressCallback:
  * @stats: a #GgitTransferProgress.
